==> haskell-optparse-applicative-0.14.2.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-applicative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-applicative
version: 0.14.2.0
id: optparse-applicative-0.14.2.0-9kyxyRchQbFAqjd86Eq9p0
key: optparse-applicative-0.14.2.0-9kyxyRchQbFAqjd86Eq9p0
license: BSD-3-Clause
copyright: (c) 2012-2017 Paolo Capriotti <paolo@capriotti.io>
maintainer: huw.campbell@gmail.com
author: Paolo Capriotti, Huw Campbell
homepage: https://github.com/pcapriotti/optparse-applicative
synopsis: Utilities and combinators for parsing command line options
description:
    optparse-applicative is a haskell library for parsing options
    on the command line, providing a powerful applicative interface
    for composing these options.
    .
    optparse-applicative takes care of reading and validating the
    arguments passed to the command line, handling and reporting
    errors, generating a usage line, a comprehensive help screen,
    and enabling context-sensitive bash completions.
    .
    See the included README for detailed instructions and examples,
    which is also available on github
    <https://github.com/pcapriotti/optparse-applicative>.
category: System, CLI, Options, Parsing
abi: 95062ad3096c4edbb683dde606d8f8f9
exposed: True
exposed-modules:
    Options.Applicative Options.Applicative.Arrows
    Options.Applicative.BashCompletion Options.Applicative.Builder
    Options.Applicative.Builder.Completer
    Options.Applicative.Builder.Internal Options.Applicative.Common
    Options.Applicative.Extra Options.Applicative.Help
    Options.Applicative.Help.Chunk Options.Applicative.Help.Core
    Options.Applicative.Help.Levenshtein
    Options.Applicative.Help.Pretty Options.Applicative.Help.Types
    Options.Applicative.Internal Options.Applicative.Types
import-dirs: /usr/lib/ghc-8.4.2/site-local/optparse-applicative-0.14.2.0
library-dirs: /usr/lib/ghc-8.4.2/site-local/optparse-applicative-0.14.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/optparse-applicative-0.14.2.0
hs-libraries: HSoptparse-applicative-0.14.2.0-9kyxyRchQbFAqjd86Eq9p0
depends:
    base-4.11.1.0 transformers-0.5.5.0
    transformers-compat-0.5.1.4-BG7wgRauI8h5onKXiYZE4l process-1.6.3.0
    ansi-wl-pprint-0.6.8.2-IJ5p3rykDYPJYLxT8JDwNB
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             transformers-0.5.5.0=02be5c4dc3fdc926cf1b36bd484a25f8
             transformers-compat-0.5.1.4-BG7wgRauI8h5onKXiYZE4l=61c266daf0974ee97d7e012fc3e96535
             process-1.6.3.0=f742183dfb18804fd4a4a0e3c09be01d
             ansi-wl-pprint-0.6.8.2-IJ5p3rykDYPJYLxT8JDwNB=26c7be0bee3c07028ffca6c8a89c2e02
haddock-interfaces: /usr/share/doc/haskell-optparse-applicative/html/optparse-applicative.haddock
haddock-html: /usr/share/doc/haskell-optparse-applicative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-applicative-0.14.2.0-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-applicative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-applicative
version: 0.14.2.0
id: optparse-applicative-0.14.2.0-62exsxKF348IVCVPqReofC
key: optparse-applicative-0.14.2.0-62exsxKF348IVCVPqReofC
license: BSD-3-Clause
copyright: (c) 2012-2017 Paolo Capriotti <paolo@capriotti.io>
maintainer: huw.campbell@gmail.com
author: Paolo Capriotti, Huw Campbell
homepage: https://github.com/pcapriotti/optparse-applicative
synopsis: Utilities and combinators for parsing command line options
description:
    optparse-applicative is a haskell library for parsing options
    on the command line, providing a powerful applicative interface
    for composing these options.
    .
    optparse-applicative takes care of reading and validating the
    arguments passed to the command line, handling and reporting
    errors, generating a usage line, a comprehensive help screen,
    and enabling context-sensitive bash completions.
    .
    See the included README for detailed instructions and examples,
    which is also available on github
    <https://github.com/pcapriotti/optparse-applicative>.
category: System, CLI, Options, Parsing
abi: 2081310a648400eda979d50e9a2f1447
exposed: True
exposed-modules:
    Options.Applicative Options.Applicative.Arrows
    Options.Applicative.BashCompletion Options.Applicative.Builder
    Options.Applicative.Builder.Completer
    Options.Applicative.Builder.Internal Options.Applicative.Common
    Options.Applicative.Extra Options.Applicative.Help
    Options.Applicative.Help.Chunk Options.Applicative.Help.Core
    Options.Applicative.Help.Levenshtein
    Options.Applicative.Help.Pretty Options.Applicative.Help.Types
    Options.Applicative.Internal Options.Applicative.Types
import-dirs: /usr/lib/ghc-8.4.2/site-local/optparse-applicative-0.14.2.0
library-dirs: /usr/lib/ghc-8.4.2/site-local/optparse-applicative-0.14.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/optparse-applicative-0.14.2.0
hs-libraries: HSoptparse-applicative-0.14.2.0-62exsxKF348IVCVPqReofC
depends:
    base-4.11.1.0 transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W process-1.6.3.0
    ansi-wl-pprint-0.6.8.2-5VjUR5zrHF4ICjKXehuybH
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             transformers-0.5.5.0=02be5c4dc3fdc926cf1b36bd484a25f8
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=63a0e01576545fb684fe201dfb63f95d
             process-1.6.3.0=f742183dfb18804fd4a4a0e3c09be01d
             ansi-wl-pprint-0.6.8.2-5VjUR5zrHF4ICjKXehuybH=acacaf200daa6a34897880ee2dd48291
haddock-interfaces: /usr/share/doc/haskell-optparse-applicative/html/optparse-applicative.haddock
haddock-html: /usr/share/doc/haskell-optparse-applicative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
